import acm.program.*;
import java.util.*;

public class AnimalHipsters extends ConsoleProgram {
	public void run() {
		HashMap<String, ArrayList<String>> network = buildNetwork();
		HashMap<String, String> favorites = buildFavorites();
		
		println("Here are all the animal hipsters, in no particular order: ");
		for (String hipster: findAnimalHipsters(network, favorites)) {
			println("  " + hipster);
		}
	}
	
	/**
	 * Builds and returns the social network described in the handout.
	 * 
	 * @return The social network from the handout.
	 */
	private HashMap<String, ArrayList<String>> buildNetwork() {
		HashMap<String, ArrayList<String>> network = new HashMap<String, ArrayList<String>>();
		
		/* Add the people to the network. */
		addPerson(network, "Amy");
		addPerson(network, "Brie");
		addPerson(network, "Chris");
		addPerson(network, "Devney");
		addPerson(network, "Elena");
		addPerson(network, "Fan-Hal");
		
		/* Add links between them. */
		addLink(network, "Amy", "Brie");
		addLink(network, "Amy", "Chris");
		addLink(network, "Brie", "Chris");
		addLink(network, "Brie", "Devney");
		addLink(network, "Brie", "Elena");
		addLink(network, "Chris", "Elena");
		addLink(network, "Chris", "Fan-Hal");
		addLink(network, "Devney", "Elena");
		addLink(network, "Elena", "Fan-Hal");
		
		return network;
	}
	
	/**
	 * Adds a person to a social network.
	 * 
	 * @param network The network to add to.
	 * @param person The name of that person.
	 */
	private void addPerson(HashMap<String, ArrayList<String>> network, String person) {
		network.put(person, new ArrayList<String>());
	}
	
	/**
	 * Adds a new bidirectional link to a social network.
	 * 
	 * @param network The network to add to.
	 * @param p1 The first person
	 * @param p2 The second person
	 */
	private void addLink(HashMap<String, ArrayList<String>> network, String p1, String p2) {
		network.get(p1).add(p2);
		network.get(p2).add(p1);
	}
	
	/**
	 * Builds and returns the animal favorites map from the handout.
	 * 
	 * @return The animal favorites map from the handout.
	 */
	private HashMap<String, String> buildFavorites() {
		HashMap<String, String> result = new HashMap<String, String>();
		result.put("Amy", "Quokka");
		result.put("Brie", "Springbok");
		result.put("Chris", "Nubian Ibex");
		result.put("Devney", "Springbok");
		result.put("Elena", "Quokka");
		result.put("Fan-Hal", "Springbok");
		return result;
	}
	
	/**
	 * Given a social network and a map of everyone's favorite animals, returns a list
	 * of everyone who's an animal hipster.
	 * 
	 * @param network The social network.
	 * @param favoriteAnimals Everyone's favorite animals.
	 * @return A list of all the animal hipsters.
	 */
	private ArrayList<String> findAnimalHipsters(HashMap<String, ArrayList<String>> network,
			                                     HashMap<String, String> favoriteAnimals) {
		// TODO: Replace this comment with your implementation.
		return new ArrayList<String>();
	}
}
