import acm.program.*;
import acm.graphics.*;

public class Kerning extends GraphicsProgram {
	/* The images for the letters V and A. */
	private static final boolean[][] A = {
		{ false, false, false, false, true,  false, false, false, false },
		{ false, false, false, false, true,  false, false, false, false },
		{ false, false, false, true,  false, true,  false, false, false },
		{ false, false, false, true,  false, true,  false, false, false },
		{ false, false, true,  false, false, false, true,  false, false },
		{ false, false, true,  false, false, false, true,  false, false },
		{ false, true,  true,  true,  true,  true,  true,  true,  false },
		{ false, true,  false, false, false, false, false, true,  false },
		{ false, true,  false, false, false, false, false, true,  false },
		{ true,  true,  true,  false, false, false, true,  true,  true  }
	};
	private static final boolean[][] V = {
		{ true , true , true , false, false, false, true , true , true  },
		{ false, true , false, false, false, false, false, true,  false },
		{ false, true , false, false, false, false, false, true , false },
		{ false, true , false, false, false, false, false, true , false },
		{ false, false, true , false, false, false, true , false, false },
		{ false, false, true,  false, false, false, true,  false, false },
		{ false, false, false, true , false, true , false, false, false },
		{ false, false, false, true,  false, true,  false, false, false },
		{ false, false, false, false, true , false, false, false, false },
		{ false, false, false, false, true , false, false, false, false },
	};

	/* The maximum possible kern. */
	private static final int MAX_KERN = Math.min(A[0].length, V[0].length);

	public void run() { 
		int kernAmount = getDialog().readInt("Enter kern amount: ");
		while (kernAmount < 0 || kernAmount > MAX_KERN) {
			kernAmount = getDialog().readInt("Enter kern amount: ");
		}
		drawPicture(kern(V, A, kernAmount));
	}


	/**
	 * Draws the given boolean[][] grid on the screen.
	 * 
	 * @param grid The grid to draw.
	 */
	private void drawPicture(boolean[][] arr) {		
		/* Determine the appropriate size for the image. */
		double cellHeight = getHeight() / (double)arr.length;
		double cellWidth  = getWidth()  / (double)arr[0].length;

		/* Draw each cell. */
		for (int x = 0; x < arr[0].length; x++) {
			for (int y = 0; y < arr.length; y++) {
				GRect cell = new GRect(x * cellWidth, y * cellHeight, cellWidth, cellHeight);
				if (arr[y][x]) cell.setFilled(true);
				add(cell);
			}
		}
	}

	/**
	 * Given two letter images represented by boolean[][] grids and a kerning amount,
	 * kerns the two images and returns the result.
	 * 
	 * @param first The first image.
	 * @param second The second image.
	 * @param kern The amount by which to kern.
	 * @return The image formed by kerning the two images.
	 */
	private boolean[][] kern(boolean[][] first, boolean[][] second, int kern) {
		// TODO: Replace this implementation with your own.
		return new boolean[1][1];
	}
}
